@@ -1,7 +1,7 @@
 # coding: utf8
 # Part of the bioread package for reading BIOPAC data.
 #
-# Copyright (c) 2016 Board of Regents of the University of Wisconsin System
+# Copyright (c) 2020 Board of Regents of the University of Wisconsin System
 #
 # Written Nate Vack <njvack@wisc.edu> with research from John Ollinger
 # at the Waisman Laboratory for Brain Imaging and Behavior, University of
@@ -26,4 +26,4 @@ def test_acq_info_runs(capsys):
     acq_info.main([DATA_FILE])
     out, err = capsys.readouterr()
     assert len(out) > 0
-    assert 'Tue Feb  2 16:30:56 2016' in out
+    assert '2016-02-02' in out
